# enp

enp (stands for Everything in NumPy) provides implementation of deep learning, machine learning, and math algorithms in
NumPy or pure Python.

## Installation

You can install the library using pip:

    pip install enp

## Description

The library consists of 3 main parts:

- deep learning (examples of usage can be found in examples/nn folder)
- machine learning (examples of usage are in examples/ml folder)
- linear algebra (examples of usage are in tests/test_linear_algebra.py)


